@@ -159,8 +159,13 @@ fillHzGaps <- function(x, flag = TRUE, to_top = 0, to_bottom = max(x)) {
   res <- res[order(res[[idn]], res[[htb[1]]]),]
 
   # re-calculate unique hzID (note: AFTER reorder)
-  res$hzID <- as.character(1:nrow(res))
-
+  if (is.null(res$hzID) || !is.numeric(as.numeric(res$hzID))) {
+   res$hzID <- as.character(1:nrow(res))
+  } else {
+   nahz <- is.na(res$hzID)
+   res$hzID[nahz] <- max(as.numeric(res$hzID), na.rm = TRUE) + seq_len(sum(nahz))
+  }
+  
   # replace horizons (use df class in object x)
   replaceHorizons(x) <- .as.data.frame.aqp(res, aqp_df_class(x))
 
