@@ -18,7 +18,9 @@
 # function requires at least two attributes
 # hard coded reference to s$id
 # set k to 0 for no depth weighting
-#' Numerical Soil Profile Comparison
+#' Deprecated: Numerical Soil Profile Comparison
+#'
+#' See `NCSP()` for the modern interface to numerical soil profile comparison/classification.
 #'
 #' Performs a numerical comparison of soil profiles using named properties,
 #' based on a weighted, summed, depth-segment-aligned dissimilarity
@@ -93,9 +95,7 @@
 #' results (FALSE)
 #' @param strict_hz_eval should horizons be strictly checked for internal
 #' self-consistency? (FALSE)
-#' @param progress 'none' (default): argument passed to \code{ddply} and
-#' related functions, see \code{\link{create_progress_bar}} for all possible
-#' options; 'text' is usually fine.
+#' @param progress 'none' (default)
 #' @param plot.depth.matrix should a plot of the 'soil'/'non-soil' matrix be
 #' returned (FALSE)
 #' @param rescale.result should the result be rescaled by dividing by max(D)
@@ -111,114 +111,20 @@
 #'  - Moore, A.; Russell, J. & Ward, W. Numerical analysis of soils: A comparison of three soil profile models with field classification. Journal of Soil Science, 1972, 23, 194-209.
 #' @keywords methods manip
 #' @examples
-#'
-#' \donttest{
-#' ## 1. check out the influence depth-weight coef:
-#' library(lattice)
-#'
-#' z <- rep(1:100,4)
-#' k <- rep(c(0,0.1,0.05,0.01), each=100)
-#' w <- 100*exp(-k*z)
-#'
-#' xyplot(z ~ w, groups=k, ylim=c(105,-5), xlim=c(-5,105), type='l',
-#'        ylab='Depth', xlab='Weighting Factor', asp=1.5,
-#'        auto.key=list(columns=4, lines=TRUE, points=FALSE, title="k", cex=0.8, size=3),
-#'        panel=function(...) {
-#'          panel.grid(h=-1,v=-1)
-#'          panel.superpose(...)
-#'        }
-#' )
-#'
-#' # more soil properties
-#' data(sp2)
-#' depths(sp2) <- id ~ top + bottom
-#'
-#' d.1 <- profile_compare(sp2, vars=c('prop','field_ph','hue','value'),
-#'                        max_d=100, k=0.01, plot.depth.matrix=TRUE)
-#'
-#' # add some missing data:
-#' sp2$prop[1:2] <- NA
-#' d.2 <- profile_compare(sp2, vars=c('prop','field_ph','hue','value'),
-#'                        max_d=100, k=0.01, plot.depth.matrix=TRUE)
-#'
-#' # note small changes in D:
-#' cor(d.1, d.2)
-#'
-#' ## 3. identify profiles within a collection that contain all NAs
-#' set.seed(1010101)
-#' s <- pbindlist(lapply(letters[1:10], random_profile, SPC=TRUE))
-#'
-#' # replace first profile's data with NA
-#' na.required <- nrow(s[1, ])
-#' s$p1[1:na.required] <- NA
-#' s$p2[1:na.required] <- NA
-#'
-#' # attempt profile comparison: this won't work, throws an error
-#' d <- profile_compare(s, vars=c('p1','p2'), max_d=100, k=0)
-#'
-#' # check for soils that are missing all clay / total RF data
-#' f.check.NA <- function(i) length(which(is.na(i$p1) | is.na(i$p2))) / nrow(i) == 1
-#' missing.too.much.data.idx <- which(profileApply(s, f.check.NA))
-#'
-#' # remove bad profiles and try again: works
-#' s.no.na <- profile_compare(s[-missing.too.much.data.idx, ],
-#'                            vars=c('p1','p2'),
-#'                            max_d=100, k=0, plot.depth.matrix=TRUE)
-#'
-#' ## 4. better plotting of dendrograms with ape package:
-#' if(require(ape) & require(cluster) & require(MASS)) {
-#'
-#'   data(sp2)
-#'   depths(sp2) <- id ~ top + bottom
-#'   site(sp2) <- ~ surface
-#'
-#'   d <- profile_compare(sp2, vars=c('prop','field_ph','hue','value'),
-#'                          max_d=100, k=0)
-#'
-#'   h <- diana(d)
-#'   p <- as.phylo(as.hclust(h))
-#'   plot(p, show.tip.label=FALSE)
-#'   tiplabels(sp2$surface, col=cutree(h, 3), bg=NA, cex=0.75)
-#'
-#'   ## 5. other uses of the dissimilarity matrix
-#'   # Sammon Mapping: doesn't like '0' values in dissimilarity matrix
-#'   d.sam <- sammon(d)
-#'
-#'   # simple plot
-#'   dev.off() ; dev.new()
-#'   plot(d.sam$points, type = "n", xlim=range(d.sam$points[,1] * 1.5))
-#'   text(d.sam$points, labels=row.names(as.data.frame(d.sam$points)),
-#'        cex=0.75, col=cutree(h, 3))
-#'
-#' }
-#'
-#'
-#' ## 6. try out the 'sample_interval' argument
-#' # compute using sucessively larger sampling intervals
-#' data(sp3)
-#' d <- profile_compare(sp3, vars=c('clay','cec','ph'),
-#'                      max_d=100, k=0.01)
-#' d.2 <- profile_compare(sp3, vars=c('clay','cec','ph'),
-#'                        max_d=100, k=0.01, sample_interval=2)
-#' d.10 <- profile_compare(sp3, vars=c('clay','cec','ph'),
-#'                         max_d=100, k=0.01, sample_interval=10)
-#' d.20 <- profile_compare(sp3, vars=c('clay','cec','ph'),
-#'                         max_d=100, k=0.01, sample_interval=20)
-#'
-#' # check the results via hclust / dendrograms
-#' oldpar <- par(mfcol=c(1,4), mar=c(2,1,2,2))
-#' plot(as.dendrogram(hclust(d)), horiz=TRUE, main='Every Depth Slice')
-#' plot(as.dendrogram(hclust(d.2)), horiz=TRUE, main='Every 2nd Depth Slice')
-#' plot(as.dendrogram(hclust(d.10)), horiz=TRUE, main='Every 10th Depth Slice')
-#' plot(as.dendrogram(hclust(d.20)), horiz=TRUE, main='Every 20th Depth Slice')
-#' par(oldpar)
-#'
-#' }
-#'
+#' # See ?NCSP for examples
+#' @rdname profile_compare
+#' @export
 pc <- function(s, vars, max_d, k, filter=NULL, sample_interval=NA, replace_na=TRUE,
 add_soil_flag=TRUE, return_depth_distances=FALSE, strict_hz_eval=FALSE, progress='none',
 plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 
+  # as of aqp 2.0
+  .Deprecated(new = 'NCSP', old = "profile_compare", msg = 'profile_compare() has been deprecated, please use NCSP()')
+  
+  if (!requireNamespace("plyr")) {
+    stop("package `plyr` is required to use `profile_compare()`; use `NCSP()` instead or install the `plyr` package", call. = FALSE)
+  }
+  
 	# currently this will only work with integer depths
 	# test by attempting to cast to integers
 	# if there is no difference, then we are fine
@@ -256,7 +162,7 @@ plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 	# compute a weighting vector based on k
 	w <- 1 * exp(-k * depth_slice_seq)
 
-	## TODO: convert to slice() (#7)
+	## TODO: convert to dice() (#7)
 	## BUG: !!! this step re-orders via string-factor-string conversion step by split() (#7)
 	## --> this is only a bug when profile IDs have been altered after SPC init
 	## --> https://stackoverflow.com/questions/17611734/r-split-preserving-natural-order-of-factors
@@ -264,7 +170,7 @@ plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 	## unroll each named soil property, for each soil profile
 	## the result is a list matrices with dimensions: depth, num_properties
 	# this approach requires a named list of soil properties
-	s.unrolled <- dlply(s, "id", .progress=progress, .fun=function(di, p=vars, d=max_d, strict=strict_hz_eval, .parallel=getOption('AQP_parallel', default=FALSE)) {
+	s.unrolled <- plyr::dlply(s, "id", .progress=progress, .fun=function(di, p=vars, d=max_d, strict=strict_hz_eval, .parallel=getOption('AQP_parallel', default=FALSE)) {
 
 		# iterate over the set of properties, unrolling as we go
 		# the result is a [z by p] matrix unrolled to max_d
@@ -345,7 +251,7 @@ plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 	ow <- options('warn')
 	options(warn=-1)
 
-	d <- llply(depth_slice_seq, .parallel=getOption('AQP_parallel', default=FALSE), .progress=progress, .fun=function(i, su=s.unrolled) {
+	d <- plyr::llply(depth_slice_seq, .parallel=getOption('AQP_parallel', default=FALSE), .progress=progress, .fun=function(i, su=s.unrolled) {
     
 	  
 	  ## 2021-03-03
@@ -371,7 +277,7 @@ plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 	  ## TODO: don't call daisy on bogus input data, temp fix: disable warnings (#7)
 	  ## if all of the input to daisy is NA, then we get warnings from min() and max()
 	  ## this happens when we set a max depth that is beyond most profiles
-	  d.i <- daisy(sp, metric='gower')
+	  d.i <- cluster::daisy(sp, metric='gower')
 		return(d.i)
 	  }
 	)
@@ -488,8 +394,17 @@ plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 	}
 
 
+#' @param s A SoilProfileCollection
+#' @param vars Variable names
+#' @param rescale.result Rescale result? Default: FALSE
+#' @param ... Additional arguments passed to `profile_compare()`
+#'
+#' @rdname profile_compare
+#' @export
 pc.SPC <- function(s, vars, rescale.result=FALSE, ...){
 
+  .Deprecated('NCSP', old = "profile_compare")
+  
 	if(!requireNamespace("scales", quietly = TRUE))
 	  stop("package `scales` is required", call.=FALSE)
 
@@ -556,7 +471,7 @@ pc.SPC <- function(s, vars, rescale.result=FALSE, ...){
 		# rescale to [0,1]
 
 		message(paste('site-level variables included:', paste(site.vars, collapse=', ')))
-		d.site <- daisy(s.site[, site.vars, drop=FALSE], metric='gower')
+		d.site <- cluster::daisy(s.site[, site.vars, drop=FALSE], metric='gower')
 		
 		# re-scale to [0,1]
 		d.site <- .rescaleRange(d.site, x0 = 0, x1 = 1)
@@ -620,8 +535,11 @@ pc.SPC <- function(s, vars, rescale.result=FALSE, ...){
 setGeneric("profile_compare", function(s, ...) standardGeneric("profile_compare"))
 
 # temp interface to SPC class objects
-
+#' @export
+#' @rdname profile_compare
 setMethod(f='profile_compare', signature='SoilProfileCollection', definition=pc.SPC)
 
 # temp interface for dataframes
+#' @export
+#' @rdname profile_compare
 setMethod(f='profile_compare', signature='data.frame', definition=pc)
